@@ -40,12 +40,8 @@ impl Serialize for Value {
     }
 }
 
+#[derive(Default)]
 pub struct Serializer {}
-impl Default for Serializer {
-    fn default() -> Self {
-        Self {}
-    }
-}
 
 impl serde::Serializer for Serializer {
     type Ok = Value;
